@@ -11,14 +11,14 @@ use {
         instruction::{AccountMeta, Instruction},
         program_pack::Pack,
         pubkey::Pubkey,
-        system_instruction, sysvar,
+        stake, system_instruction, sysvar,
     },
     solana_program_test::*,
     solana_sdk::{
         instruction::InstructionError, signature::Keypair, signature::Signer,
         transaction::Transaction, transaction::TransactionError, transport::TransportError,
     },
-    spl_stake_pool::{error, id, instruction, stake_program, state},
+    spl_stake_pool::{error, id, instruction, state},
 };
 
 async fn create_required_accounts(
@@ -53,11 +53,11 @@ async fn create_required_accounts(
         payer,
         recent_blockhash,
         &stake_pool_accounts.reserve_stake,
-        &stake_program::Authorized {
+        &stake::state::Authorized {
             staker: stake_pool_accounts.withdraw_authority,
             withdrawer: stake_pool_accounts.withdraw_authority,
         },
-        &stake_program::Lockup::default(),
+        &stake::state::Lockup::default(),
         1,
     )
     .await;
@@ -454,10 +454,107 @@ async fn fail_with_wrong_token_program_id() {
     .await
     .unwrap();
 
+    create_token_account(
+        &mut banks_client,
+        &payer,
+        &recent_blockhash,
+        &stake_pool_accounts.pool_fee_account,
+        &stake_pool_accounts.pool_mint.pubkey(),
+        &stake_pool_accounts.manager.pubkey(),
+    )
+    .await
+    .unwrap();
+
+    let rent = banks_client.get_rent().await.unwrap();
+    let rent_stake_pool = rent.minimum_balance(get_packed_len::<state::StakePool>());
+    let validator_list_size = get_instance_packed_len(&state::ValidatorList::new(
+        stake_pool_accounts.max_validators,
+    ))
+    .unwrap();
+    let rent_validator_list = rent.minimum_balance(validator_list_size);
+
+    let mut transaction = Transaction::new_with_payer(
+        &[
+            system_instruction::create_account(
+                &payer.pubkey(),
+                &stake_pool_accounts.stake_pool.pubkey(),
+                rent_stake_pool,
+                get_packed_len::<state::StakePool>() as u64,
+                &id(),
+            ),
+            system_instruction::create_account(
+                &payer.pubkey(),
+                &stake_pool_accounts.validator_list.pubkey(),
+                rent_validator_list,
+                validator_list_size as u64,
+                &id(),
+            ),
+            instruction::initialize(
+                &id(),
+                &stake_pool_accounts.stake_pool.pubkey(),
+                &stake_pool_accounts.manager.pubkey(),
+                &stake_pool_accounts.staker.pubkey(),
+                &stake_pool_accounts.validator_list.pubkey(),
+                &stake_pool_accounts.reserve_stake.pubkey(),
+                &stake_pool_accounts.pool_mint.pubkey(),
+                &stake_pool_accounts.pool_fee_account.pubkey(),
+                &wrong_token_program.pubkey(),
+                None,
+                stake_pool_accounts.epoch_fee,
+                stake_pool_accounts.withdrawal_fee,
+                stake_pool_accounts.deposit_fee,
+                stake_pool_accounts.referral_fee,
+                stake_pool_accounts.max_validators,
+            ),
+        ],
+        Some(&payer.pubkey()),
+    );
+    transaction.sign(
+        &[
+            &payer,
+            &stake_pool_accounts.stake_pool,
+            &stake_pool_accounts.validator_list,
+            &stake_pool_accounts.manager,
+        ],
+        recent_blockhash,
+    );
+    let transaction_error = banks_client
+        .process_transaction(transaction)
+        .await
+        .err()
+        .unwrap();
+
+    match transaction_error {
+        TransportError::TransactionError(TransactionError::InstructionError(_, error)) => {
+            assert_eq!(error, InstructionError::IncorrectProgramId);
+        }
+        _ => panic!(
+            "Wrong error occurs while try to initialize stake pool with wrong token program ID"
+        ),
+    }
+}
+
+#[tokio::test]
+async fn fail_with_fee_owned_by_wrong_token_program_id() {
+    let (mut banks_client, payer, recent_blockhash) = program_test().start().await;
+    let stake_pool_accounts = StakePoolAccounts::new();
+
+    let wrong_token_program = Keypair::new();
+
+    create_mint(
+        &mut banks_client,
+        &payer,
+        &recent_blockhash,
+        &stake_pool_accounts.pool_mint,
+        &stake_pool_accounts.withdraw_authority,
+    )
+    .await
+    .unwrap();
+
     let rent = banks_client.get_rent().await.unwrap();
 
     let account_rent = rent.minimum_balance(spl_token::state::Account::LEN);
-    let mut transaction = Transaction::new_with_payer(
+    let transaction = Transaction::new_signed_with_payer(
         &[system_instruction::create_account(
             &payer.pubkey(),
             &stake_pool_accounts.pool_fee_account.pubkey(),
@@ -466,8 +563,6 @@ async fn fail_with_wrong_token_program_id() {
             &wrong_token_program.pubkey(),
         )],
         Some(&payer.pubkey()),
-    );
-    transaction.sign(
         &[&payer, &stake_pool_accounts.pool_fee_account],
         recent_blockhash,
     );
@@ -979,11 +1074,11 @@ async fn fail_with_bad_reserve() {
             &payer,
             &recent_blockhash,
             &bad_stake,
-            &stake_program::Authorized {
+            &stake::state::Authorized {
                 staker: wrong_authority,
                 withdrawer: stake_pool_accounts.withdraw_authority,
             },
-            &stake_program::Lockup::default(),
+            &stake::state::Lockup::default(),
             1,
         )
         .await;
@@ -1029,11 +1124,11 @@ async fn fail_with_bad_reserve() {
             &payer,
             &recent_blockhash,
             &bad_stake,
-            &stake_program::Authorized {
+            &stake::state::Authorized {
                 staker: stake_pool_accounts.withdraw_authority,
                 withdrawer: wrong_authority,
             },
-            &stake_program::Lockup::default(),
+            &stake::state::Lockup::default(),
             1,
         )
         .await;
@@ -1079,13 +1174,13 @@ async fn fail_with_bad_reserve() {
             &payer,
             &recent_blockhash,
             &bad_stake,
-            &stake_program::Authorized {
+            &stake::state::Authorized {
                 staker: stake_pool_accounts.withdraw_authority,
                 withdrawer: stake_pool_accounts.withdraw_authority,
             },
-            &stake_program::Lockup {
+            &stake::state::Lockup {
                 custodian: wrong_authority,
-                ..stake_program::Lockup::default()
+                ..stake::state::Lockup::default()
             },
             1,
         )
@@ -1128,15 +1223,15 @@ async fn fail_with_bad_reserve() {
     {
         let bad_stake = Keypair::new();
         let rent = banks_client.get_rent().await.unwrap();
-        let lamports = rent.minimum_balance(std::mem::size_of::<stake_program::StakeState>());
+        let lamports = rent.minimum_balance(std::mem::size_of::<stake::state::StakeState>());
 
         let transaction = Transaction::new_signed_with_payer(
             &[system_instruction::create_account(
                 &payer.pubkey(),
                 &bad_stake.pubkey(),
                 lamports,
-                std::mem::size_of::<stake_program::StakeState>() as u64,
-                &stake_program::id(),
+                std::mem::size_of::<stake::state::StakeState>() as u64,
+                &stake::program::id(),
             )],
             Some(&payer.pubkey()),
             &[&payer, &bad_stake],
@@ -1180,11 +1275,11 @@ async fn fail_with_bad_reserve() {
 }
 
 #[tokio::test]
-async fn success_with_required_stake_deposit_authority() {
+async fn success_with_deposit_authority() {
     let (mut banks_client, payer, recent_blockhash) = program_test().start().await;
-    let stake_deposit_authority = Keypair::new();
-    let stake_pool_accounts =
-        StakePoolAccounts::new_with_stake_deposit_authority(stake_deposit_authority);
+    let deposit_authority = Keypair::new();
+    let stake_pool_accounts = StakePoolAccounts::new_with_deposit_authority(deposit_authority);
+    let deposit_authority = stake_pool_accounts.stake_deposit_authority;
     stake_pool_accounts
         .initialize_stake_pool(&mut banks_client, &payer, &recent_blockhash, 1)
         .await
@@ -1195,8 +1290,6 @@ async fn success_with_required_stake_deposit_authority() {
         get_account(&mut banks_client, &stake_pool_accounts.stake_pool.pubkey()).await;
     let stake_pool =
         try_from_slice_unchecked::<state::StakePool>(stake_pool_account.data.as_slice()).unwrap();
-    assert_eq!(
-        stake_pool.stake_deposit_authority,
-        stake_pool_accounts.stake_deposit_authority
-    );
+    assert_eq!(stake_pool.stake_deposit_authority, deposit_authority);
+    assert_eq!(stake_pool.sol_deposit_authority.unwrap(), deposit_authority);
 }
