@@ -11,7 +11,7 @@ use {
         hash::Hash,
         instruction::{AccountMeta, Instruction, InstructionError},
         pubkey::Pubkey,
-        sysvar,
+        stake, sysvar,
     },
     solana_program_test::*,
     solana_sdk::{
@@ -19,9 +19,7 @@ use {
         transaction::{Transaction, TransactionError},
         transport::TransportError,
     },
-    spl_stake_pool::{
-        error::StakePoolError, id, instruction, minimum_stake_lamports, stake_program, state,
-    },
+    spl_stake_pool::{error::StakePoolError, id, instruction, minimum_stake_lamports, state},
     spl_token::error::TokenError,
 };
 
@@ -298,10 +296,10 @@ async fn _success(test_type: SuccessTestType) {
     let validator_stake_account =
         get_account(&mut banks_client, &validator_stake_account.stake_account).await;
     let stake_state =
-        deserialize::<stake_program::StakeState>(&validator_stake_account.data).unwrap();
+        deserialize::<stake::state::StakeState>(&validator_stake_account.data).unwrap();
     let meta = stake_state.meta().unwrap();
     assert_eq!(
-        validator_stake_account.lamports - minimum_stake_lamports(meta),
+        validator_stake_account.lamports - minimum_stake_lamports(&meta),
         validator_stake_item.active_stake_lamports
     );
 
@@ -856,7 +854,7 @@ async fn success_with_reserve() {
 
     let deposit_lamports = TEST_STAKE_AMOUNT;
     let rent = context.banks_client.get_rent().await.unwrap();
-    let stake_rent = rent.minimum_balance(std::mem::size_of::<stake_program::StakeState>());
+    let stake_rent = rent.minimum_balance(std::mem::size_of::<stake::state::StakeState>());
 
     let deposit_info = simple_deposit_stake(
         &mut context.banks_client,
@@ -994,15 +992,30 @@ async fn success_with_reserve() {
     assert!(error.is_none());
 
     // first and only deposit, lamports:pool 1:1
-    let tokens_deposit_fee =
-        stake_pool_accounts.calculate_deposit_fee(deposit_info.stake_lamports + stake_rent);
-    let tokens_withdrawal_fee =
-        stake_pool_accounts.calculate_withdrawal_fee(deposit_info.pool_tokens);
+    let stake_pool = get_account(
+        &mut context.banks_client,
+        &stake_pool_accounts.stake_pool.pubkey(),
+    )
+    .await;
+    let stake_pool =
+        try_from_slice_unchecked::<state::StakePool>(stake_pool.data.as_slice()).unwrap();
+    // the entire deposit is actually stake since it isn't activated, so only
+    // the stake deposit fee is charged
+    let deposit_fee = stake_pool
+        .calc_pool_tokens_stake_deposit_fee(stake_rent + deposit_info.stake_lamports)
+        .unwrap();
     assert_eq!(
-        deposit_info.stake_lamports + stake_rent - tokens_deposit_fee,
+        deposit_info.stake_lamports + stake_rent - deposit_fee,
         deposit_info.pool_tokens,
+        "stake {} rent {} deposit fee {} pool tokens {}",
+        deposit_info.stake_lamports,
+        stake_rent,
+        deposit_fee,
+        deposit_info.pool_tokens
     );
 
+    let withdrawal_fee = stake_pool_accounts.calculate_withdrawal_fee(deposit_info.pool_tokens);
+
     // Check tokens used
     let user_token_balance = get_token_balance(
         &mut context.banks_client,
@@ -1017,15 +1030,10 @@ async fn success_with_reserve() {
         &stake_pool_accounts.reserve_stake.pubkey(),
     )
     .await;
-    let stake_state =
-        deserialize::<stake_program::StakeState>(&reserve_stake_account.data).unwrap();
+    let stake_state = deserialize::<stake::state::StakeState>(&reserve_stake_account.data).unwrap();
     let meta = stake_state.meta().unwrap();
-    // TODO: these numbers dont add up even with +tokens_deposit_fee
     assert_eq!(
-        initial_reserve_lamports
-            + meta.rent_exempt_reserve
-            + tokens_withdrawal_fee
-            + tokens_deposit_fee,
+        initial_reserve_lamports + meta.rent_exempt_reserve + withdrawal_fee + deposit_fee,
         reserve_stake_account.lamports
     );
 
@@ -1035,8 +1043,8 @@ async fn success_with_reserve() {
     assert_eq!(
         user_stake_recipient_account.lamports,
         initial_stake_lamports + deposit_info.stake_lamports + stake_rent
-            - tokens_withdrawal_fee
-            - tokens_deposit_fee
+            - withdrawal_fee
+            - deposit_fee
     );
 }
 
@@ -1222,7 +1230,7 @@ async fn success_withdraw_from_transient() {
 
     let deposit_lamports = TEST_STAKE_AMOUNT;
     let rent = context.banks_client.get_rent().await.unwrap();
-    let stake_rent = rent.minimum_balance(std::mem::size_of::<stake_program::StakeState>());
+    let stake_rent = rent.minimum_balance(std::mem::size_of::<stake::state::StakeState>());
 
     let deposit_info = simple_deposit_stake(
         &mut context.banks_client,
@@ -1417,3 +1425,118 @@ async fn success_withdraw_all_fee_tokens() {
     .await;
     assert_eq!(fee_tokens, 0);
 }
+
+#[tokio::test]
+async fn success_empty_out_stake_with_fee() {
+    let (
+        mut banks_client,
+        payer,
+        recent_blockhash,
+        stake_pool_accounts,
+        _,
+        deposit_info,
+        user_transfer_authority,
+        user_stake_recipient,
+        tokens_to_withdraw,
+    ) = setup().await;
+
+    // add another validator and deposit into it
+    let other_validator_stake_account = simple_add_validator_to_pool(
+        &mut banks_client,
+        &payer,
+        &recent_blockhash,
+        &stake_pool_accounts,
+    )
+    .await;
+
+    let other_deposit_info = simple_deposit_stake(
+        &mut banks_client,
+        &payer,
+        &recent_blockhash,
+        &stake_pool_accounts,
+        &other_validator_stake_account,
+        TEST_STAKE_AMOUNT,
+    )
+    .await
+    .unwrap();
+
+    // move tokens to new account
+    transfer_spl_tokens(
+        &mut banks_client,
+        &payer,
+        &recent_blockhash,
+        &deposit_info.pool_account.pubkey(),
+        &other_deposit_info.pool_account.pubkey(),
+        &user_transfer_authority,
+        tokens_to_withdraw,
+    )
+    .await;
+
+    let user_tokens =
+        get_token_balance(&mut banks_client, &other_deposit_info.pool_account.pubkey()).await;
+
+    let user_transfer_authority = Keypair::new();
+    delegate_tokens(
+        &mut banks_client,
+        &payer,
+        &recent_blockhash,
+        &other_deposit_info.pool_account.pubkey(),
+        &other_deposit_info.authority,
+        &user_transfer_authority.pubkey(),
+        user_tokens,
+    )
+    .await;
+
+    // calculate exactly how much to withdraw, given the fee, to get the account
+    // down to 0, using an inverse fee calculation
+    let validator_stake_account = get_account(
+        &mut banks_client,
+        &other_validator_stake_account.stake_account,
+    )
+    .await;
+    let stake_state =
+        deserialize::<stake::state::StakeState>(&validator_stake_account.data).unwrap();
+    let meta = stake_state.meta().unwrap();
+    let lamports_to_withdraw = validator_stake_account.lamports - minimum_stake_lamports(&meta);
+    let stake_pool_account =
+        get_account(&mut banks_client, &stake_pool_accounts.stake_pool.pubkey()).await;
+    let stake_pool =
+        try_from_slice_unchecked::<state::StakePool>(stake_pool_account.data.as_slice()).unwrap();
+    let fee = stake_pool.stake_withdrawal_fee;
+    let inverse_fee = state::Fee {
+        numerator: fee.denominator - fee.numerator,
+        denominator: fee.denominator,
+    };
+    let pool_tokens_to_withdraw =
+        lamports_to_withdraw * inverse_fee.denominator / inverse_fee.numerator;
+
+    let new_authority = Pubkey::new_unique();
+    let error = stake_pool_accounts
+        .withdraw_stake(
+            &mut banks_client,
+            &payer,
+            &recent_blockhash,
+            &user_stake_recipient.pubkey(),
+            &user_transfer_authority,
+            &other_deposit_info.pool_account.pubkey(),
+            &other_validator_stake_account.stake_account,
+            &new_authority,
+            pool_tokens_to_withdraw,
+        )
+        .await;
+    assert!(error.is_none());
+
+    // Check balance of validator stake account is MINIMUM + rent-exemption
+    let validator_stake_account = get_account(
+        &mut banks_client,
+        &other_validator_stake_account.stake_account,
+    )
+    .await;
+    let stake_state =
+        deserialize::<stake::state::StakeState>(&validator_stake_account.data).unwrap();
+    let meta = stake_state.meta().unwrap();
+    assert_eq!(
+        validator_stake_account.lamports,
+        minimum_stake_lamports(&meta)
+    );
+}
